@@ -6,52 +6,39 @@ from astrape.exceptions.exceptions import *
 from astrape.constants.astrape_constants import *
 from typing import Union, List, Dict, Any, Optional, cast, Tuple
 import math 
-import torchmetrics
+import numpy as np
+
 applicable_val_metric_list = APPLICABLE_VAL_METRIC_LIST
 applicable_optimizer_type_list = APPLICABLE_OPTIMIZER_TYPE_LIST
 
-"""
-Below are classes of which foundate Pytorch-Lightning Models defined in "models_lightning.py".
-i.e., they are the parent classes of the classes in "models_lightning.py".
 
-The classes below specifies the i) training/validation/prediction/test step operations
-                                ii) optimizer configurations
-                                iii) methods for resetting/initializing model weights
-
-
-    
-
-
-"""
-# *****************************************************************  Classes  ***************************************************************** 
-
-########################################################## BaseNet (Begins) ##########################################################
-
-"""
-BaseNet (offspring of pl.LightningModule): 
-
-    BaseNet is the parent class for MLPs(MLP, ContractingMLP, CustomMLP). It is also
-    compatible with other MLPs that are written in pytorch_lightning.
-
-    When inheriting BaseNet, you only need to specify the structure of your MLP because 
-    other magics are defined in BaseNet.  
-
-    BaseNet can perform both classification and regression tasks. If you specify n_classes, 
-    BaseNet will recognize the task as a classification problem. If n_classes is not passed
-    as a parameter for BaseNet, it will understand that the task is a regression problem.
-
-    Arguments: 
-        - dims (Union[int, tuple[int]]): The dimension of the data. e.g., 4, (8,8,1)
-
-        - n_classes (Optional[int]) : Number of classes (labels) in the classification task.
-                                      Do not specify this argument (set is as None) when you 
-                                      are performing regression tasks.
-
-        - **config (Any) : Hyperparameters that can be shared among different models. 
-                           e.g., optimizer_type, lr, weight_decay, batch_size, bn, dropout_p, etc.
-                
-"""
 class BaseNet(pl.LightningModule):
+    r"""BaseNet. Use this for models that don't deal with image data. 
+
+        Attributes:
+            
+            dims (int or tuple of int): Dimension of data with # of samples removed.
+            
+            n_classes (int or None): Number of classes in classification task. None if it is a regression task.
+            
+            config (dict): Hyperparameter configurations.
+
+            sample_weight (torch.Tensor or np.ndarray): Sample weights.
+
+            **kwargs (Any): Attributes of LightningModule
+
+        Note:
+
+            BaseNet is the parent class for MLPs(MLP, ContractingMLP, CustomMLP). It is also
+            compatible with other MLPs that are written in pytorch_lightning.
+
+            When inheriting BaseNet, you only need to specify the structure of your MLP because 
+            other magics are defined in BaseNet.  
+
+            BaseNet can perform both classification and regression tasks. If you specify n_classes, 
+            BaseNet will recognize the task as a classification problem. If n_classes is not passed
+            as a parameter for BaseNet, it will understand that the task is a regression problem.
+    """
 
     def __init__(
         self,
@@ -61,7 +48,15 @@ class BaseNet(pl.LightningModule):
         sample_weight : Optional[Union["np.ndarray", "torch.Tensor"]] = None,
         **config : Any
     ) -> None:
+        r"""
+         Args: 
+            
+            dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1)
 
+            n_classes (int, optional): Number of classes (labels) in the classification task. Do not specify this argument (set is as None) when you are performing regression tasks.
+
+            **config (Any) : Hyperparameters that can be shared among different models. e.g., optimizer_type, lr, weight_decay, batch_size, bn, dropout_p, etc.
+        """
         super(BaseNet, self).__init__()
         if isinstance(dims, tuple):
             flattened = 1
@@ -77,20 +72,16 @@ class BaseNet(pl.LightningModule):
         config.update({'l1_strength' : l1_strength})
             
         self.save_hyperparameters(*config)
-        #optimizer_type_check(applicable_optimizer_type_list, self.hparams.optimizer_type)
-
-
-    def on_after_batch_transfer(self, batch, dataloader_idx=0):
         
-        # Modify this part if you want to perform reweighting.
-        
-        self.sample_weight = torch.ones_like(batch[1]).type_as(batch[1])
-        
-
-        return batch
 
     @property
     def criterion(self):
+        r"""Criterion for loss function.
+
+        Returns:
+
+            See astrape.utilities.utils for details.
+        """
         if self.n_classes is None:
             if 'regression_metric' in self.config.keys():
                 if self.config['regression_metric'] == "mse":
@@ -151,9 +142,7 @@ class BaseNet(pl.LightningModule):
             self.log('val/acc', acc)
             self.log('val/auc', auc)
             return {'loss' : loss, 'acc' : acc, 'auc' : auc}
-        
-        
-        
+    
     def predict_step(self, pred_batch, batch_idx, dataloader_idx=0):
         x_batch, y_batch = pred_batch
         
@@ -222,45 +211,53 @@ class BaseNet(pl.LightningModule):
                                         lr=self.hparams.lr)
         
         return optimizer
-        
-########################################################## BaseNet (Ends) ##########################################################
 
 
-########################################################## ConvNet (Begins) ##########################################################
-"""
-ConvNet (offspring of pl.LightningModule): 
-
-
-    II. ConvNet (offspring of pl.LightningModule):
-    ConvNet is the parent class for CNNs(VGG, UNet). It is also compatible with other CNNs
-    that are written in pytorch_lightning. 
-
-    When inheriting ConvNet, you only need to specify the structure of your MLP because 
-    other magics are defined in ConvNet. 
-
-    Currently in expytorch_lightning v. 0.0.0, ConvNet only supports basic classification
-    tasks such as classification using CE loss or dice loss. Other operations will be 
-    updated soon(Be tuned!).
-
-
-    Arguments: 
-
-        - model_type (pl.LightningModule) : The class of the model that you will use.
-
-        - n_classes (Optional[int]) : Number of classes (labels) in the classification task.
-                                    
-        - **config (Any) : Hyperparameters that can be shared among different models. 
-                           e.g., optimizer_type, lr, weight_decay, batch_size, bn, dropout_p, etc.
-                
-"""
 class ConvNet(pl.LightningModule):
+    r"""ConvNet. Use this when using CNNs. 
+
+    Note:
+
+        ConvNet is the parent class for CNNs(VGG, UNet). It is also compatible with other CNNs
+        that are written in pytorch_lightning. 
+
+        When inheriting ConvNet, you only need to specify the structure of your MLP because 
+        other magics are defined in ConvNet. 
+
+        Currently in expytorch_lightning v. 0.0.0, ConvNet only supports basic classification
+        tasks such as classification using CE loss or dice loss. Other operations will be 
+        updated soon(Be tuned!).
+
+    Attributes:
+
+        model_type (LightningModule): The class of the model that you will use.
+
+        n_classes (int, optional): Number of classes in the classification task. Leave it as None in regression tasks.
+
+        sample_weight (torch.Tensor or np.ndarray): Sample weights.
+
+        config (dict) : Hyperparameters that can be shared among different models. e.g., optimizer_type, lr, weight_decay, batch_size, bn, dropout_p, etc.
+"""
     def __init__(
         self,
         model_type : "pl.LightningModule",
         n_classes : Optional[int] = None,
         sample_weight : Optional[Union["np.ndarray", "torch.Tensor"]] = None,
         **config : Any
-    ) -> None:
+    )->None:
+        r"""
+        Args: 
+
+            model_type (LightningModule): The class of the model that you will use.
+
+            n_classes (int, optional): Number of classes in the classification task. Leave it as None in regression tasks.
+                Default: ``None``
+            
+            sample_weight (torch.Tensor or np.ndarray): Sample weights.
+                Default: ``None``
+
+            **config (Any) : Hyperparameters that can be shared among different models. e.g., optimizer_type, lr, weight_decay, batch_size, bn, dropout_p, etc.
+        """
         super(ConvNet, self).__init__()
 
         if 'optimizer_type' not in config.keys():
@@ -274,6 +271,12 @@ class ConvNet(pl.LightningModule):
 
     @property
     def criterion(self):   
+        r"""Criterion for loss function.
+
+        Returns:
+
+            See astrape.utilities.utils for details.
+        """
         if self.n_classes is None:
             if 'regression_metric' in self.config.keys():
                 if self.config['regression_metric'] == "mse":
@@ -406,9 +409,6 @@ class ConvNet(pl.LightningModule):
                 nn.init.constant_(module.bias, 0)
 
     def configure_optimizers(self):
-
-        #optimizer_type_check(applicable_optimizer_type_list, self.hparams.optimizer_type)
-
         if self.hparams.optimizer_type == "adam":
             optimizer = torch.optim.Adam(self.parameters(),
                                      lr=self.hparams.lr,
@@ -417,6 +417,4 @@ class ConvNet(pl.LightningModule):
             optimizer = torch.optim.SGD(self.parameters(),
                                         lr=self.hparams.lr)
 
-        return optimizer
-
-########################################################## ConvNet (Ends) ##########################################################
\ No newline at end of file
+        return optimizer
\ No newline at end of file
