@@ -17,6 +17,12 @@ import warnings
 warnings.filterwarnings(action='ignore')
 
 class Experiment(BaseExperiment):
+    r"""
+
+    Note:
+        This class is just BaseExperiment with cross_validation.
+        See astrape.base.experiment_base for details.
+    """
     def __init__(
         self,
         project_name : str,
@@ -29,7 +35,7 @@ class Experiment(BaseExperiment):
         stack_models : bool = True,
         random_number : int = 0,
         path : Optional[str] = None
-    ) -> None:
+    )->None:
        
         super().__init__(
             project_name=project_name,
@@ -43,18 +49,18 @@ class Experiment(BaseExperiment):
             random_number=random_number,
             path=path
         )
-    #######################################################################  cross_validation (Begins)  ####################################################################### 
     def cross_validation(
         self,
         model_type : Union["BaseEstimator", "pl.LightningModule"],
         parameters : Dict[str, List[Any]],
         search_type : str = "random",
         val_metric : str = 'val/acc',
+        mode : Optional[str] = None,
         trainer_config : Optional[Dict] = None,
         n_random_search : Optional[int] = None,
         cv : int = 5,
         random_number : int = DEFAULT_RANDOM_SEED_NUMBER 
-    ):
+    )->tuple[Union["pl.LightningModule", "BaseEstimator"],dict]:
         self.fit_or_cv = "CV"
         self.update_log_path()
         best_model_structure, info = CrossValidation(
@@ -72,12 +78,13 @@ class Experiment(BaseExperiment):
             parameters=parameters,
             trainer_config=trainer_config,
             val_metric=val_metric,
+            mode=mode,
             cv=cv,
             search_type=search_type,
             n_random_search=n_random_search,
             random_number=random_number
         ).search()
         self.fit_or_cv = "FIT"
-        return best_model_structure, info
+        return (best_model_structure, info)
         
     
\ No newline at end of file
