@@ -16,6 +16,32 @@ This is a child class of BaseExperiment that performs stratified K-fold cross va
 the type of the model (e.g., MLP, UNet) and its candidates of hyperparameters are given. 
 """
 class CrossValidation(BaseExperiment):
+    r"""Performs stratified K-fold cross validation.
+
+    Attributes:
+
+        rng: Random number generator.
+
+        seed_num (int): Random seed number. 
+
+        trainer_config (dict): Trainer configurations.
+
+        search_type (str): "grid" or "random".
+
+        parameters (dict): Dictionary specifying sets of hyperparameters.
+
+        val_metric (str): The validation metric.
+
+        cv (int): Number of folds. i.e., K in stratified K-fold cross validation.
+
+        jsonlog_dir (str): Path where json files will be logged.
+
+        ckpt_dir (str): Path where model checkpoints will be logged. 
+
+        best_val_score (float): The best validation score.
+
+        n_random_search (int): Number of sampling from distribution when performing random search. 
+    """
 
     def __init__(
         self,
@@ -32,7 +58,8 @@ class CrossValidation(BaseExperiment):
         model_type : Union["BaseEstimator", "pl.LightningModule"],
         parameters : Dict[str, List[Any]],
         trainer_config : Optional[Dict],
-        val_metric: str ='val/acc',
+        val_metric : str ='val/acc',
+        mode : Optional[str] = None,
         cv : int = 5,
         search_type : str = 'random',
         n_random_search : Optional[int] = None,
@@ -40,27 +67,79 @@ class CrossValidation(BaseExperiment):
     ):
 
         """
-        parameters : Dict[str, List[Any]]   dictionary of each key being a hyperparameter(including optimizer_type), and each value being a list of candidates of such key
-            example for 'parameters': 
-                                           { 
-                                               "n_layer_1": {
-                                                # Choose from pre-defined values
-                                                "values": [32, 64, 128, 256, 512]
-                                                },
-                                                "n_layer_2": {
-                                                # Choose from pre-defined values
-                                                "values": [32, 64, 128, 256, 512, 1024]
-                                                },
-                                                "lr": {
-                                                    # log uniform distribution between exp(min) and exp(max)
-                                                    "distribution": "log_scale_uniform",
-                                                    "min": -9.21,   # exp(-9.21) = 1e-4
-                                                    "max": -4.61    # exp(-4.61) = 1e-2
-                                                }
-                                            }
-        trainer_config : dict    dictionary of trainer configurations
-        val_metric :  str     'val/acc' or 'val/loss'
-        
+
+        Args:
+
+            project_name (str): Name of the project. Directory of {path}/{project_name} will be created.
+
+            X (np.ndarray or torch.Tensor or pd.DataFrame): Data for the project. If X_test is not specified, X would be splitted(stratify=y) into train/val data with a given random state.
+
+            y (np.ndarray or torch.Tensor or pd.DataFrame): Labels for the project. If y_test is not specified, y would be splitted(stratify=y) into train/val labels with a given random state.
+
+            X_train (torch.Tensor): Training data.   
+
+            y_train (torch.Tensor): Training labels.
+
+            X_val (np.ndarray or torch.Tensor or pd.DataFrame, optional): Validation data if explicitly exists.   
+
+            y_val (np.ndarray or torch.Tensor or pd.DataFrame, optional): Validation labels if explicitly exists.
+
+            X_test (np.ndarray or torch.Tensor or pd.DataFrame, optional): Test data if explicitly exists.
+            
+            y_test (np.ndarray or torch.Tensor or pd.DataFrame, optional): Test labels if explicitly exists.
+
+            test_size (float): Test(and validation) size when splitting the data.
+                
+            n_classes (int): Number of classes for the classification task. Don't specify this when performing regression tasks.
+
+            path (str): Base path for the project. Default is the current directory.
+
+            model_type (`LightningModule`, `BaseEstimator): The type of model (class)
+
+            parameters (dict): Dictionary specifying sets of hyperparameters.
+
+            trainer_config (dict): Trainer configurations. 
+                Default: ``None``
+            
+            val_metric (str): The validation metric.
+                Default: ``'val/acc'``
+
+            mode (str): Mode for validation metric. Either "min" or "max". If left as None, mode will automatically be set for 'val/acc', 'val/auc', and 'val/loss'. If the metric is not one of these, error will be raised.
+                Default: ``None``
+
+            cv (int): K in K-fold cross validation.
+                Default: ``5``
+
+            search_type (str): Search type of the cross validation. Should be "random" or "grid".
+                Default: ``'random'``
+
+            n_random_search (int, optional): Number of sampling from distribution when performing random search. If None, will be set to 5.
+                Default: ``None``
+
+            random_number (int): Random number for random number generator.
+                Default: ``2022``
+
+        Example::
+            
+            >>> parameters= { 
+                                "n_layer_1": {
+                                # Choose from pre-defined values
+                                "values": [32, 64, 128, 256, 512]
+                                },
+                                "n_layer_2": {
+                                # Choose from pre-defined values
+                                "values": [32, 64, 128, 256, 512, 1024]
+                                },
+                                "lr": {
+                                    # log uniform distribution between exp(min) and exp(max)
+                                    "distribution": "log_scale_uniform",
+                                    "min": -9.21,   # exp(-9.21) = 1e-4
+                                    "max": -4.61    # exp(-4.61) = 1e-2
+                                }
+                            }
+        Returns:
+
+            None
         """
         self.rng = np.random.default_rng(random_number)
         self.seed_num = int(10**6 * self.rng.random(1))
@@ -89,7 +168,13 @@ class CrossValidation(BaseExperiment):
             self.parameters.update({'batch_size' : {'values' : [DEFAULT_BATCH_SIZE]}})
         self.jsonlog_dir = None
         self.ckpt_dir = None
-        self.mode = 'max' if val_metric == 'val/acc' else 'min'
+        if not mode:
+            if val_metric == 'val/loss':
+                self.mode = 'min'
+            elif val_metric in ['val/acc', 'val/auc']:
+                self.mode = 'max'
+            else:
+                raise AssertionError("You should specify the mode if val_metric is not one of 'val/acc', 'val/loss', or 'val/auc'.")
         self.best_val_score = None
         self.n_random_search = 5 if not n_random_search else n_random_search
 
@@ -102,7 +187,13 @@ class CrossValidation(BaseExperiment):
         return cv_indices
 
 
-    def get_hparam_info(self):
+    def get_hparam_info(self)->dict:
+        r"""Get informations of ``parameters``.
+
+        Returns:
+
+            dict: Information of ``parameters``.
+        """
         hparam_info = {}
         for hparam_name, hparam_config in self.parameters.items():
             if 'values' in hparam_config.keys():
@@ -117,7 +208,13 @@ class CrossValidation(BaseExperiment):
 
         return hparam_info
 
-    def get_hparams_dict_list(self):
+    def get_hparams_dict_list(self)->List[dict]:
+        r"""Get set of hyperparameter candidates.
+
+        Returns:
+
+            list: List of hyperparametr candidates.
+        """
         hparams_dict_list = []
         hparam_info = self.get_hparam_info()
         if self.search_type == 'random':
@@ -172,7 +269,13 @@ class CrossValidation(BaseExperiment):
         X_test : Optional["np.ndarray"] = None,
         y_test : Optional["np.ndarray"] = None,
         test_size : float = 0.01
-    ):  
+    )->Union["pl.LightningDataModule", tuple["np.ndarray","np.ndarray","np.ndarray","np.ndarray","np.ndarray","np.ndarray"]]:
+        r"""Gets datamodule.
+        
+        Returns:
+
+            :obj:`LightningDataModule` or tuple: The datamodule. Returns tuple of numpy ndarrays when using sklearn models.
+        """
         if BaseEstimator in inspect.getmro(self.model_type):
             if (X_val or y_val) and not (X_val and y_val):
                 raise ValueError("X_val and y_val should have the same # of samples.")
@@ -206,7 +309,13 @@ class CrossValidation(BaseExperiment):
 
         return data_module
 
-    def search(self):
+    def search(self)->tuple[Union["pl.LightningModule", "BaseEstimator"], dict]:
+        r"""Performs cross-validation.
+
+        Returns:
+
+            tuple: The best model structure and its information.
+        """
         self.fit_or_cv = "CV"
         self.update_log_path()
         cv_indices = self.get_cv_indices()
@@ -276,4 +385,4 @@ class CrossValidation(BaseExperiment):
             self.val_metric : self.best_val_score
         }
         self.fit_or_cv = "FIT"
-        return self.best_model_structure, info                    
+        return (self.best_model_structure, info)                    
