@@ -30,7 +30,7 @@ class DoubleConv(nn.Module):
                 negative_slope = 1e-2
             layers.append(nn.LeakyReLU(negative_slope=negative_slope, inplace=True))
         else:
-            raise ValueError("Wrong name {} for activation function.".format(activation_type))
+            raise ValueError(f"Wrong name {activation_type} for activation function.")
         
         layers.append(nn.Conv2d(out_ch, out_ch, kernel_size=3, padding=1))
         if bn:
@@ -44,7 +44,7 @@ class DoubleConv(nn.Module):
                 negative_slope = 1e-2
             layers.append(nn.LeakyReLU(negative_slope=negative_slope, inplace=True))
         else:
-            raise ValueError("Wrong name {} for activation function.".format(activation_type))
+            raise ValueError(f"Wrong name {activation_type} for activation function.")
         
         
         self.net = nn.Sequential(*layers)
