@@ -108,7 +108,7 @@ class _MLP(nn.Module):
                     negative_slope = 1e-2
                 layers.append(nn.LeakyReLU(negative_slope=negative_slope))
             else:
-                raise ValueError("Wrong name {} for activation function.".format(activation_type))
+                raise ValueError(f"Wrong name {activation_type} for activation function.")
             layers.append(nn.Dropout(self.dropout_p))
             
             for i in range(self.n_layers-2):
@@ -126,7 +126,7 @@ class _MLP(nn.Module):
                         negative_slope = 1e-2
                     layers.append(nn.LeakyReLU(negative_slope=negative_slope))
                 else:
-                    raise ValueError("Wrong name {} for activation function.".format(activation_type))
+                    raise ValueError(f"Wrong name {activation_type} for activation function.")
                 layers.append(nn.Dropout(self.dropout_p))
 
             
@@ -205,7 +205,7 @@ class MLP(BaseNet):
         # sanity check. Check if right arguments are declared.
         for key in hparams.keys():
             if key not in entire_keys:
-                raise ValueError('Wrong argument {} is passed to the model.'.format(key))
+                raise ValueError(f'Wrong argument {key} is passed to the model.')
         self.model = _MLP(dims=self.dims, n_classes=self.n_classes, sample_weight=self.sample_weight, **hparams)
 
     def forward(self, X):
@@ -321,7 +321,7 @@ class _ContractingMLP(nn.Module):
                     negative_slope = 1e-2
                 layers.append(nn.LeakyReLU(negative_slope=negative_slope))
             else:
-                raise ValueError("Wrong name {} for activation function.".format(activation_type))
+                raise ValueError(f"Wrong name {activation_type} for activation function.")
             
             layers.append(nn.Dropout(self.dropout_p))
 
@@ -344,7 +344,7 @@ class _ContractingMLP(nn.Module):
                         negative_slope = 1e-2
                     layers.append(nn.LeakyReLU(negative_slope=negative_slope))
                 else:
-                    raise ValueError("Wrong name {} for activation function.".format(activation_type))
+                    raise ValueError(f"Wrong name {activation_type} for activation function.")
                 
                 layers.append(nn.Dropout(self.dropout_p))
                 
@@ -524,7 +524,7 @@ class _CustomMLP(nn.Module):
                     negative_slope = 1e-2
                 layers.append(nn.LeakyReLU(negative_slope=negative_slope))
             else:
-                raise ValueError("Wrong name {} for activation function.".format(activation_type))
+                raise ValueError(f"Wrong name {activation_type} for activation function.")
             layers.append(nn.Dropout(self.dropout_p))
             the_rest = self.n_hidden_units_list[1:]
             for idx in range(len(the_rest-1)):
@@ -540,7 +540,7 @@ class _CustomMLP(nn.Module):
                         negative_slope = 1e-2
                     layers.append(nn.LeakyReLU(negative_slope=negative_slope))
                 else:
-                    raise ValueError("Wrong name {} for activation function.".format(activation_type))
+                    raise ValueError(f"Wrong name {activation_type} for activation function.")
                 layers.append(nn.Dropout(self.dropout_p))
             
             if self.n_classes > 2:
@@ -600,7 +600,7 @@ class CustomMLP(BaseNet):
         # n_hidden_units_list
         for n_hidden_units in self.n_hidden_units_list:
             if n_hidden_units <=0:
-                raise ValueError("Number of hidden units can't be less than or equal to 0.")
+                raise ValueError(f"Number of hidden units can't be less than or equal to 0.")
 
         super(CustomMLP, self).__init__(
             dims=dims,
@@ -679,7 +679,7 @@ class _VGG(nn.Module):
                 negative_slope = 1e-2
             layers.append(nn.LeakyReLU(negative_slope=negative_slope))
         else:
-            raise ValueError("Wrong name {} for activation function.".format(activation_type))
+            raise ValueError(f"Wrong name {activation_type} for activation function.")
 
         layers.append(nn.Dropout(p=self.dropout_p))
         layers.append(nn.Linear(4096, 4096))
@@ -692,7 +692,7 @@ class _VGG(nn.Module):
                 negative_slope = 1e-2
             layers.append(nn.LeakyReLU(negative_slope=negative_slope))
         else:
-            raise ValueError("Wrong name {} for activation function.".format(activation_type))
+            raise ValueError(f"Wrong name {activation_type} for activation function.")
         layers.append(nn.Dropout(p=self.dropout_p))
         layers.append(nn.Linear(4096, n_classes))
         
@@ -732,7 +732,7 @@ class _VGG(nn.Module):
                         negative_slope = 1e-2
                     layers.append(nn.LeakyReLU(negative_slope=self.negative_slope))
                 else:
-                    raise ValueError("Wrong name {} for activation function.".format(self.activation_type))
+                    raise ValueError(f"Wrong name {self.activation_type} for activation function.")
                 in_channels = v
 
         return nn.Sequential(*layers)    
@@ -943,10 +943,7 @@ class UNet(ConvNet):
             'features_start' : 64,
             'bilinear' : False
         }
-        
-        
-        
-        
+         
         # set default for model-specific hyperparameters
         for argument, default in default_parameter_dict.items():
             if argument not in hparams.keys(): 
@@ -968,7 +965,7 @@ class UNet(ConvNet):
         # sanity check. Check if right arguments are declared.
         for key in hparams.keys():
             if key not in entire_keys:
-                raise ValueError('Wrong argument is passed to the model.')
+                raise ValueError(f'Wrong argument is passed to the model.')
         self.model = _UNet(
             n_classes=n_classes, 
             dims=dims, 
@@ -980,24 +977,6 @@ class UNet(ConvNet):
         return self.model.forward(X)
     
     
-    
-    def help(self) -> None :
-        whoami = "U-Net. \n\n"
-        helptext = "Parameters ------------------------------------------------------------------------------------------------------- \n"
-        helptext += "n_classes: int \t Number of classes in the classification task. If it is binary classification, n_classes=2\n"
-        helptext += "In defining hyperparameters and optimizer_type, we recommend you to define a dictionary.\n"
-        helptext += "Define a dictionary containing :\n\t"
-        helptext += "-'optimizer_type': str (default='adam')\n\t" 
-        helptext += "-'n_hidden_units': int (default=10)\n\t"
-        helptext += "-'weight_decay' : 0< float < 1\n\t"
-        helptext += "-'depth' : int (default=5)\n\t"
-        helptext += "-'bilinear': bool (default=True)\n\t"
-        helptext += "-'lr' : float (default=1e-4)."
-        
-        text= whoami + helptext
-        print(text)
-    
-    
 """
 
 TODO : Implement GoogleNet
